@@ -41,16 +41,19 @@ double exponent(double x)
 }
 
 Diagram::Diagram()
- : warnColor(1.0,0.0,0.0,Lum::OS::display->blackColor),
+ : backgroundColor(1.0,1.0,1.0,Lum::OS::display->whiteColor),
+   warnColor(1.0,0.0,0.0,Lum::OS::display->blackColor),
    limitColor(1.0,0.0,0.0,Lum::OS::display->blackColor),
    valueGoodColor(0.95,0.95,0.95,Lum::OS::display->blackColor),
    valueGoodFrameColor(0.64,0.64,0.64,Lum::OS::display->blackColor),
    valueBadColor(1.0,0.82,0.82,Lum::OS::display->blackColor),
    valueBadFrameColor(0.8,0.58,0.58,Lum::OS::display->blackColor),
+   scaleColor(0.7,0.7,0.7,Lum::OS::display->blackColor),
+   textColor(0.7,0.7,0.7,Lum::OS::display->blackColor),
    font(Lum::OS::display->GetFont(Lum::OS::Display::fontScaleFootnote)),
    mode(modeFullDay)
 {
-  SetBackground(Lum::OS::display->GetFill(Lum::OS::Display::graphBackgroundFillIndex));
+  SetBackground(Lum::OS::display->GetFill(Lum::OS::Display::boxedBackgroundFillIndex));
 
   Observe(topWeight);
   Observe(bottomWeight);
@@ -277,8 +280,8 @@ void Diagram::PrintData(Lum::OS::DrawInfo* draw,
             }
 
             // Point outside diagram: Interpolate position on right diagram border
-            if (lx2>this->x+this->width-1) {
-              lx2=this->x+this->width-1;
+            if (lx2>this->x+(int)this->width-1) {
+              lx2=this->x+(int)this->width-1;
               ly2=((lx2-px)*(cy-py))/(cx-px)+py;
             }
 
@@ -319,7 +322,6 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
   std::wstring        tmp;
   Lum::Base::Calendar day;
 
-  draw->PushForeground(Lum::OS::Display::graphScaleColor);
   draw->PushFont(font);
 
   draw->PushClip(this->x+weightUnitWidth,this->y,this->width-weightUnitWidth-valueUnitWidth,this->height);
@@ -328,9 +330,20 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
   int xPos=this->x+((hAdjustment->GetTop()-1)/dayWidth)*dayWidth-(hAdjustment->GetTop()-1);
   while (xPos<this->x+(int)width) {
 
+    draw->PushForeground(scaleColor);
     switch (mode) {
     case modeFullDay:
+    case modeSmallDay:
       draw->DrawLine(xPos+dayWidth-1,this->y,xPos+dayWidth-1,this->y+height-1);
+      break;
+    default:
+      break;
+    }
+    draw->PopForeground();
+
+    draw->PushForeground(textColor);
+    switch (mode) {
+    case modeFullDay:
       tmp=Lum::Base::Calendar::GetWeekDayNameShort(day.GetDayOfWeek());
       draw->DrawString(xPos+(dayWidth-font->StringWidth(tmp))/2,this->y+height-3*font->height+font->ascent,tmp);
 
@@ -341,7 +354,6 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
       draw->DrawString(xPos+(dayWidth-font->StringWidth(tmp))/2,this->y+height-font->height+font->ascent,tmp);
       break;
     case modeSmallDay:
-      draw->DrawLine(xPos+dayWidth-1,this->y,xPos+dayWidth-1,this->y+height-1);
       tmp=Lum::Base::NumberToWString(day.GetDayOfMonth())+L".";
       draw->DrawString(xPos+(dayWidth-font->StringWidth(tmp))/2,
                        this->y+font->ascent+height-font->height,
@@ -358,6 +370,7 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
       }
       break;
     }
+    draw->PopForeground();
 
     day.AddDays(1);
     xPos+=dayWidth;
@@ -366,7 +379,6 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
   draw->PopClip();
 
   draw->PopFont();
-  draw->PopForeground();
 }
 
 /**
@@ -374,7 +386,7 @@ void Diagram::PrintHorizontalScale(Lum::OS::DrawInfo* draw,
  */
 void Diagram::PrintVerticalScale(Lum::OS::DrawInfo* draw)
 {
-  draw->PushForeground(Lum::OS::Display::graphScaleColor);
+  draw->PushForeground(scaleColor);
   draw->PushFont(font);
 
   size_t step;
@@ -503,6 +515,10 @@ void Diagram::Draw(int x, int y, size_t w, size_t h)
   Lum::Base::Calendar start=data.GetStartDate();
   Lum::Base::Calendar end;
 
+  draw->PushForeground(backgroundColor);
+  draw->FillRectangle(this->x,this->y,width,height);
+  draw->PopForeground();
+
   start.AddDays((hAdjustment->GetTop()-1)/dayWidth);
   end=start;
   end.AddDays((width+dayWidth/2)/dayWidth);
@@ -527,7 +543,8 @@ bool Diagram::HandleMouseEvent(const Lum::OS::MouseEvent& event)
     gestureStartX=event.x;
     gestureStartY=event.y;
 
-    if (GetWindow()->IsDoubleClicked()) {
+    if (GetWindow()->IsDoubleClicked() &&
+        PointIsIn(GetWindow()->GetLastButtonClickEvent())) {
       Lum::Base::Calendar day=data.GetStartDate();
 
       day.AddDays((event.x-x+hAdjustment->GetTop()-1)/GetDayWidth());
