@@ -118,35 +118,47 @@ public:
                                                 Lum::Def::Desc(_(L"MAIN_TAB_DIAGRAM",L"Diagram")),
                                                 Lum::View::Create(diagram,true,true)));
 
-    Lum::OS::display->GetBehaviour()->ApplyMultiViewDlg(this,multiView);
+    Lum::Def::Menu *preMenu=Lum::Def::Menu::Create();
 
-    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
-
-    menu
+    preMenu
       ->GroupProject()
-        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_IMPORT_FOOD_COMPONENTS",L"_Import food..."))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_IMPORT_FOOD_COMPONENTS",L"_Import food"))
                                   .SetShortcut(Lum::OS::qualifierControl,L"i"),
-                                  importAction))
-        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_EXPORT_FOOD_COMPONENTS",L"_Export food..."))
+                                  importAction)
+                 .SetOpensDialog())
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_EXPORT_FOOD_COMPONENTS",L"_Export food"))
                                   .SetShortcut(Lum::OS::qualifierControl,L"e"),
-                                  exportAction))
+                                  exportAction)
+                  .SetOpensDialog())
         ->Separator()
-        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_BACKUP",L"_Backup...")),backupAction))
-        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_RESTORE",L"_Restore...")),restoreAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_BACKUP",L"_Backup")),
+                                  backupAction)
+                 .SetOpensDialog())
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_RESTORE",L"_Restore")),
+                                  restoreAction)
+                 .SetOpensDialog())
         ->Separator()
         ->ActionQuit(GetClosedAction())
       ->End()
       ->GroupEdit()
-        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_STATISTICS",L"_Statistics...")),statisticsAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_STATISTICS",L"_Statistics")),
+                                  statisticsAction)
+                 .SetOpensDialog())
         ->Separator()
         ->ActionSettings(configAction)
-      ->End()
+      ->End();
+
+    Lum::Def::Menu *postMenu=Lum::Def::Menu::Create();
+
+    postMenu
       ->GroupHelp()
         ->ActionHelp(helpAction)
         ->ActionAbout(aboutAction)
       ->End();
 
-    SetMenu(menu);
+    multiView.SetMenu(preMenu,postMenu);
+
+    Lum::OS::display->GetBehaviour()->ApplyMultiViewDlg(this,multiView);
 
     Dialog::PreInit();
   }
